// light-theme.scss — Reveal.js presentation theme for light mkdocs-material scheme

// .reveal {
//   font-family: var(--md-text-font, 'Roboto', sans-serif);
//   color: #333;
// }

// .reveal h1,
// .reveal h2,
// .reveal h3 {
//   color: #1a237e; // indigo-ish, matching mkdocs-material default
//   font-weight: 600;
// }

// .reveal .slides section {
//   background: #fff;

// }



// etc.