// dark-theme.scss — Reveal.js presentation theme for dark mkdocs-material scheme

[data-md-color-scheme=slate] {

  // .reveal {
  //   font-family: var(--md-text-font, 'Roboto', sans-serif);
  //   color: #e0e0e0;
  // }

  // .reveal h1,
  // .reveal h2,
  // .reveal h3 {
  //   color: #82b1ff; // light blue, readable on dark
  //   font-weight: 600;
  // }

  // .reveal .slides section {
  //   background: #1e1e2e;

  // }

  // etc.

}