.reveal .slides section ul, .reveal .slides section ol {
  display: inline-block;
  text-align: left;
}
.reveal .slides section .admonition,
.reveal .slides section details[class] {
  width: var(--admon-width, 80%);
  max-width: var(--admon-max-width, none);
  margin: var(--admon-margin, 1.5625em auto);
  padding: var(--admon-padding, 0 0.6rem);
  font-size: var(--admon-font-size, 0.85em);
  text-align: var(--text-align, left);
  box-shadow: var(--admon-box-shadow, none);
  opacity: var(--admon-opacity, 1);
}
.reveal .slides section .admonition .danger,
.reveal .slides section details[class] .danger {
  border: var(--admon-border, 0.075rem solid #ff1744);
}
.reveal .slides section .admonition .note,
.reveal .slides section details[class] .note {
  border: var(--admon-border, 0.075rem solid #448aff);
}
.reveal .slides section .admonition .tip,
.reveal .slides section details[class] .tip {
  border: var(--admon-border, 0.075rem solid #00bfa5);
}
.reveal .slides section .admonition .warning,
.reveal .slides section details[class] .warning {
  border: var(--admon-border, 0.075rem solid #ff9100);
}
.reveal .slides section .admonition p,
.reveal .slides section .admonition .admonition-title,
.reveal .slides section .admonition summary,
.reveal .slides section .admonition ul,
.reveal .slides section .admonition ol,
.reveal .slides section .admonition li,
.reveal .slides section .admonition pre,
.reveal .slides section .admonition code,
.reveal .slides section details[class] p,
.reveal .slides section details[class] .admonition-title,
.reveal .slides section details[class] summary,
.reveal .slides section details[class] ul,
.reveal .slides section details[class] ol,
.reveal .slides section details[class] li,
.reveal .slides section details[class] pre,
.reveal .slides section details[class] code {
  text-align: left;
}
.reveal .slides section .twemoji {
  vertical-align: middle;
}